@@ -7,9 +7,9 @@
 #pragma once
 
 #include <QColor>
+#include <QJSValue>
 #include <QObject>
 #include <QQuickItem>
-#include <QJSValue>
 
 /**
  * Utilities for processing items to obtain colors and information useful for
@@ -18,6 +18,8 @@
 class ColorUtils : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 public:
     /**
      * Describes the contrast of an item.
@@ -28,11 +30,11 @@ public:
     };
     Q_ENUM(Brightness)
 
-    explicit ColorUtils(QObject* parent = nullptr);
+    explicit ColorUtils(QObject *parent = nullptr);
 
     /**
      * Returns whether a color is bright or dark.
-     * 
+     *
      * @code{.qml}
      * import QtQuick 2.0
      * import org.kde.kirigami 2.12 as Kirigami
@@ -47,20 +49,30 @@ public:
      *     }
      * }
      * @endcode
-     * 
+     *
      * @since 5.69
      * @since org.kde.kirigami 2.12
      */
     Q_INVOKABLE ColorUtils::Brightness brightnessForColor(const QColor &color);
 
+    /**
+     * Same Algorithm as brightnessForColor but returns a 0 to 1 value for an
+     * estimate of the equivalent gray light value (luma).
+     * 0 as full black, 1 as full white and 0.5 equivalent to a 50% gray.
+     *
+     * @since 5.81
+     * @since org.kde.kirigami 2.16
+     */
+    Q_INVOKABLE qreal grayForColor(const QColor &color);
+
     /**
      * Returns the result of overlaying the foreground color on the background
      * color.
-     * 
+     *
      * @param foreground The color to overlay on the background.
-     * 
+     *
      * @param background The color to overlay the foreground on.
-     * 
+     *
      * @code{.qml}
      * import QtQuick 2.0
      * import org.kde.kirigami 2.12 as Kirigami
@@ -69,7 +81,7 @@ public:
      *     color: Kirigami.ColorUtils.alphaBlend(Qt.rgba(0, 0, 0, 0.5), Qt.rgba(1, 1, 1, 1))
      * }
      * @endcode
-     * 
+     *
      * @since 5.69
      * @since org.kde.kirigami 2.12
      */
@@ -77,15 +89,15 @@ public:
 
     /**
      * Returns a linearly interpolated color between color one and color two.
-     * 
+     *
      * @param one The color to linearly interpolate from.
-     * 
+     *
      * @param two The color to linearly interpolate to.
-     * 
+     *
      * @param balance The balance between the two colors. 0.0 will return the
      * first color, 1.0 will return the second color. Values beyond these bounds
      * are valid, and will result in extrapolation.
-     * 
+     *
      * @code{.qml}
      * import QtQuick 2.0
      * import org.kde.kirigami 2.12 as Kirigami
@@ -94,7 +106,7 @@ public:
      *     color: Kirigami.ColorUtils.linearInterpolation("black", "white", 0.5)
      * }
      * @endcode
-     * 
+     *
      * @since 5.69
      * @since org.kde.kirigami 2.12
      */
@@ -102,13 +114,11 @@ public:
 
     /**
      * Increases or decreases the properties of `color` by fixed amounts.
-     * 
+     *
      * @param color The color to adjust.
-     * 
+     *
      * @param adjustments The adjustments to apply to the color.
-     * 
-     * @note `value` and `lightness` are aliases for the same value.
-     * 
+     *
      * @code{.js}
      * {
      *     red: null, // Range: -255 to 255
@@ -117,13 +127,12 @@ public:
      *     hue: null, // Range: -360 to 360
      *     saturation: null, // Range: -255 to 255
      *     value: null // Range: -255 to 255
-     *     lightness: null, // Range: -255 to 255
      *     alpha: null, // Range: -255 to 255
      * }
      * @endcode
-     * 
-     * @warning It is an error to adjust both RGB and HSL properties.
-     * 
+     *
+     * @warning It is an error to adjust both RGB and HSV properties.
+     *
      * @since 5.69
      * @since org.kde.kirigami 2.12
      */
@@ -131,30 +140,27 @@ public:
 
     /**
      * Smoothly scales colors.
-     * 
+     *
      * @param color The color to adjust.
-     * 
+     *
      * @param adjustments The adjustments to apply to the color. Each value must
      * be between `-100.0` and `100.0`. This indicates how far the property should
-     * be scaled from its original to the maximum if positive or to the minumum if
+     * be scaled from its original to the maximum if positive or to the minimum if
      * negative.
-     * 
-     * @note `value` and `lightness` are aliases for the same value.
-     * 
+     *
      * @code{.js}
      * {
      *     red: null
      *     green: null
      *     blue: null
      *     saturation: null
-     *     lightness: null
      *     value: null
      *     alpha: null
      * }
      * @endcode
-     * 
-     * @warning It is an error to scale both RGB and HSL properties.
-     * 
+     *
+     * @warning It is an error to scale both RGB and HSV properties.
+     *
      * @since 5.69
      * @since org.kde.kirigami 2.12
      */
@@ -188,12 +194,23 @@ public:
      */
     Q_INVOKABLE static qreal chroma(const QColor &color);
 
+    struct XYZColor {
+        qreal x = 0;
+        qreal y = 0;
+        qreal z = 0;
+    };
+
     struct LabColor {
         qreal l = 0;
         qreal a = 0;
         qreal b = 0;
     };
 
+    // Not for QML, returns the comvertion from srgb of a QColor and XYZ colorspace
+    static ColorUtils::XYZColor colorToXYZ(const QColor &color);
+
     // Not for QML, returns the comvertion from srgb of a QColor and Lab colorspace
     static ColorUtils::LabColor colorToLab(const QColor &color);
+
+    static qreal luminance(const QColor &color);
 };
